RephasingManager

Struct RephasingManager 

pub struct RephasingManager { /* private fields */ }
Rephasing manager

Manages periodic rephasing of variable polarities to help escape local minima and improve overall solver performance.

Implementations

Source

impl RephasingManager

pub fn new() -> Self

Create a new rephasing manager with default settings

Default settings:

  • Initial interval: 1000 conflicts
  • Multiplier: 1.1 (geometric increase)
  • Max interval: 1_000_000 conflicts
pub fn with_interval(initial: u64, multiplier: f64, max: u64) -> Self

Create with custom interval settings

pub fn stats(&self) -> &RephasingStats

Get statistics

pub fn should_rephase(&self, conflicts: u64) -> bool

Check if rephasing should occur at this conflict count

pub fn update_best_assignment(&mut self, assignment: &[bool])

Update best assignment for Best strategy

pub fn rephase( &mut self, strategy: RephasingStrategy, num_vars: usize, current_phases: &[bool], conflicts: u64, ) -> Vec<bool>

Perform rephasing with the given strategy

Returns new phase values for all variables

pub fn next_strategy(&self) -> RephasingStrategy

Get the next recommended rephasing strategy

Uses a cyclic pattern: Original -> Inverted -> Random -> False -> Best

pub fn reset(&mut self)

Reset to initial interval